=========
Changelog
=========

Version 0.0.6
===========

- subcommand `filter` has "all" as new default value
- additional flag `--detail` to see more output from subdcommand `filter`

Version 0.0.5 and before
===========

- add kics.io subprovider